Module memory

Module memory 

Guest-physical address ranges and memory protection types.

Structs

GuestAddress
A guest-physical address.
GuestMemoryRegion
A region of guest memory backed by a host-side mmap, registered with the hypervisor.
GuestRange
A half-open guest-physical range [base, base + size).
Protection
Memory protection bits a backend may set on a guest range.
SliceGuestMemory
In-process GuestMemory implementation backed by a single contiguous Vec<u8> keyed at a fixed base guest address.

Traits

GuestMemory
Read / write access to guest memory across one or more registered regions.