#[non_exhaustive]pub struct GuestMemoryRegion {
pub range: GuestRange,
pub slot: u32,
pub protection: Protection,
}Expand description
A region of guest memory backed by a host-side mmap, registered with the hypervisor.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.range: GuestRangeThe guest-physical range this region covers.
slot: u32The slot identifier the backend assigns; meaningful only to the backend.
protection: ProtectionThe default protection for the region at registration time.
Implementations
Sourceimpl GuestMemoryRegion
impl GuestMemoryRegion
Sourcepub fn new(range: GuestRange, slot: u32, protection: Protection) -> Self
pub fn new(range: GuestRange, slot: u32, protection: Protection) -> Self
Construct a new region.