Guest-physical address ranges and memory protection types.
Structs
- Guest
Address - A guest-physical address.
- Guest
Memory Region - A region of guest memory backed by a host-side mmap, registered with the hypervisor.
- Guest
Range - A half-open guest-physical range
[base, base + size). - Protection
- Memory protection bits a backend may set on a guest range.
- Slice
Guest Memory - In-process
GuestMemoryimplementation backed by a single contiguousVec<u8>keyed at a fixedbaseguest address.
Traits
- Guest
Memory - Read / write access to guest memory across one or more registered regions.